'use strict';

exports.__esModule = true;

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _LogMonitorEntry = require('./LogMonitorEntry');

var _LogMonitorEntry2 = _interopRequireDefault(_LogMonitorEntry);

var LogMonitor = (function () {
  function LogMonitor() {
    _classCallCheck(this, LogMonitor);
  }

  LogMonitor.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (this.props.stagedActions.length < nextProps.stagedActions.length) {
      var scrollableNode = _react.findDOMNode(this).parentElement;
      var scrollTop = scrollableNode.scrollTop;
      var offsetHeight = scrollableNode.offsetHeight;
      var scrollHeight = scrollableNode.scrollHeight;

      this.scrollDown = Math.abs(scrollHeight - (scrollTop + offsetHeight)) < 20;
    } else {
      this.scrollDown = false;
    }
  };

  LogMonitor.prototype.componentDidUpdate = function componentDidUpdate(prevProps) {
    if (prevProps.stagedActions.length < this.props.stagedActions.length && this.scrollDown) {
      var scrollableNode = _react.findDOMNode(this).parentElement;
      var offsetHeight = scrollableNode.offsetHeight;
      var scrollHeight = scrollableNode.scrollHeight;

      scrollableNode.scrollTop = scrollHeight - offsetHeight;
      this.scrollDown = false;
    }
  };

  LogMonitor.prototype.handleRollback = function handleRollback() {
    this.props.rollback();
  };

  LogMonitor.prototype.handleSweep = function handleSweep() {
    this.props.sweep();
  };

  LogMonitor.prototype.handleCommit = function handleCommit() {
    this.props.commit();
  };

  LogMonitor.prototype.handleToggleAction = function handleToggleAction(index) {
    this.props.toggleAction(index);
  };

  LogMonitor.prototype.handleReset = function handleReset() {
    this.props.reset();
  };

  LogMonitor.prototype.render = function render() {
    var elements = [];
    var _props = this.props;
    var skippedActions = _props.skippedActions;
    var stagedActions = _props.stagedActions;
    var computedStates = _props.computedStates;
    var select = _props.select;

    for (var i = 0; i < stagedActions.length; i++) {
      var action = stagedActions[i];
      var _computedStates$i = computedStates[i];
      var state = _computedStates$i.state;
      var error = _computedStates$i.error;

      elements.push(_react2['default'].createElement(_LogMonitorEntry2['default'], { key: i,
        index: i,
        select: select,
        action: action,
        state: state,
        collapsed: skippedActions[i],
        error: error,
        onActionClick: this.handleToggleAction.bind(this) }));
    }

    return _react2['default'].createElement(
      'div',
      { style: {
          fontFamily: 'monospace',
          position: 'relative'
        } },
      _react2['default'].createElement(
        'div',
        null,
        _react2['default'].createElement(
          'a',
          { onClick: this.handleReset.bind(this),
            style: { textDecoration: 'underline', cursor: 'hand' } },
          'Reset'
        )
      ),
      elements,
      _react2['default'].createElement(
        'div',
        null,
        computedStates.length > 1 && _react2['default'].createElement(
          'a',
          { onClick: this.handleRollback.bind(this),
            style: { textDecoration: 'underline', cursor: 'hand' } },
          'Rollback'
        ),
        Object.keys(skippedActions).some(function (key) {
          return skippedActions[key];
        }) && _react2['default'].createElement(
          'span',
          null,
          ' • ',
          _react2['default'].createElement(
            'a',
            { onClick: this.handleSweep.bind(this),
              style: { textDecoration: 'underline', cursor: 'hand' } },
            'Sweep'
          )
        ),
        computedStates.length > 1 && _react2['default'].createElement(
          'span',
          null,
          _react2['default'].createElement(
            'span',
            null,
            ' • '
          ),
          _react2['default'].createElement(
            'a',
            { onClick: this.handleCommit.bind(this),
              style: { textDecoration: 'underline', cursor: 'hand' } },
            'Commit'
          )
        )
      )
    );
  };

  _createClass(LogMonitor, null, [{
    key: 'propTypes',
    value: {
      computedStates: _react.PropTypes.array.isRequired,
      currentStateIndex: _react.PropTypes.number.isRequired,
      stagedActions: _react.PropTypes.array.isRequired,
      skippedActions: _react.PropTypes.object.isRequired,
      reset: _react.PropTypes.func.isRequired,
      commit: _react.PropTypes.func.isRequired,
      rollback: _react.PropTypes.func.isRequired,
      sweep: _react.PropTypes.func.isRequired,
      toggleAction: _react.PropTypes.func.isRequired,
      jumpToState: _react.PropTypes.func.isRequired,
      select: _react.PropTypes.func.isRequired
    },
    enumerable: true
  }, {
    key: 'defaultProps',
    value: {
      select: function select(state) {
        return state;
      }
    },
    enumerable: true
  }]);

  return LogMonitor;
})();

exports['default'] = LogMonitor;
module.exports = exports['default'];