'use strict';

exports.__esModule = true;

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function hsvToRgb(h, s, v) {
  var i = Math.floor(h);
  var f = h - i;
  var p = v * (1 - s);
  var q = v * (1 - f * s);
  var t = v * (1 - (1 - f) * s);
  var mod = i % 6;
  var r = [v, q, p, p, t, v][mod];
  var g = [t, v, v, q, p, p][mod];
  var b = [p, p, t, v, v, q][mod];

  return {
    r: Math.round(r * 255),
    g: Math.round(g * 255),
    b: Math.round(b * 255)
  };
}

function colorFromString(token) {
  var splitToken = token.split('');
  var finalToken = splitToken.concat(splitToken.reverse());

  var number = finalToken.reduce(function (sum, char) {
    return sum + char.charCodeAt(0);
  }, 0) * Math.abs(Math.sin(token.length));

  var h = Math.round(number * (180 / Math.PI) * token.length % 360);
  var s = number % 100 / 100;
  var v = 1;

  return hsvToRgb(h, s, v);
}

var LogMonitorEntry = (function () {
  function LogMonitorEntry() {
    _classCallCheck(this, LogMonitorEntry);
  }

  LogMonitorEntry.prototype.printState = function printState(state, error) {
    var errorText = error;
    if (!errorText) {
      try {
        return JSON.stringify(this.props.select(state));
      } catch (err) {
        errorText = 'Error selecting state.';
      }
    }

    return _react2['default'].createElement(
      'span',
      { style: {
          fontStyle: 'italic'
        } },
      '(',
      errorText,
      ')'
    );
  };

  LogMonitorEntry.prototype.handleActionClick = function handleActionClick() {
    var _props = this.props;
    var index = _props.index;
    var onActionClick = _props.onActionClick;

    if (index > 0) {
      onActionClick(index);
    }
  };

  LogMonitorEntry.prototype.render = function render() {
    var _props2 = this.props;
    var index = _props2.index;
    var error = _props2.error;
    var action = _props2.action;
    var state = _props2.state;
    var collapsed = _props2.collapsed;

    var _colorFromString = colorFromString(action.type);

    var r = _colorFromString.r;
    var g = _colorFromString.g;
    var b = _colorFromString.b;

    return _react2['default'].createElement(
      'div',
      { style: {
          textDecoration: collapsed ? 'line-through' : 'none'
        } },
      _react2['default'].createElement(
        'a',
        { onClick: this.handleActionClick.bind(this),
          style: {
            opacity: collapsed ? 0.5 : 1,
            marginTop: '1em',
            display: 'block',
            paddingBottom: '1em',
            paddingTop: '1em',
            color: 'rgb(' + r + ', ' + g + ', ' + b + ')',
            cursor: index > 0 ? 'hand' : 'default',
            WebkitUserSelect: 'none'
          } },
        JSON.stringify(action)
      ),
      !collapsed && _react2['default'].createElement(
        'p',
        { style: {
            textAlign: 'center',
            transform: 'rotate(180deg)'
          } },
        '⇧'
      ),
      !collapsed && _react2['default'].createElement(
        'div',
        { style: {
            paddingBottom: '1em',
            paddingTop: '1em',
            color: 'lightyellow'
          } },
        this.printState(state, error)
      ),
      _react2['default'].createElement('hr', { style: {
          marginBottom: '2em'
        } })
    );
  };

  _createClass(LogMonitorEntry, null, [{
    key: 'propTypes',
    value: {
      index: _react.PropTypes.number.isRequired,
      state: _react.PropTypes.object.isRequired,
      action: _react.PropTypes.object.isRequired,
      select: _react.PropTypes.func.isRequired,
      error: _react.PropTypes.string,
      onActionClick: _react.PropTypes.func.isRequired,
      collapsed: _react.PropTypes.bool
    },
    enumerable: true
  }]);

  return LogMonitorEntry;
})();

exports['default'] = LogMonitorEntry;
module.exports = exports['default'];